@@ -1,19 +1,19 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
@@ -50,15 +50,15 @@ using namespace ost;
 class MathMethods : public ScriptMethods
 {
 public:
-        bool scrRandom(void);
-        bool scrSeed(void);
+	bool scrRandom(void);
+	bool scrSeed(void);
 };
 
 class MathChecks : public ScriptChecks
 {
 public:
-        const char *chkRandom(Line *line, ScriptImage *img);
-        const char *chkSeed(Line *line, ScriptImage *img);
+	const char *chkRandom(Line *line, ScriptImage *img);
+	const char *chkSeed(Line *line, ScriptImage *img);
 };
 
 class MathRuntime : public ScriptBinder
@@ -68,82 +68,82 @@ public:
 };
 
 static Script::Define runtime[] = {
-        {"seed", false, (Script::Method)&MathMethods::scrSeed,
-                (Script::Check)&MathChecks::chkSeed},
-        {"random", false, (Script::Method)&MathMethods::scrRandom,
-                (Script::Check)&MathChecks::chkRandom},
-        {NULL, false, NULL, NULL}};   
+	{"seed", false, (Script::Method)&MathMethods::scrSeed,
+		(Script::Check)&MathChecks::chkSeed},
+	{"random", false, (Script::Method)&MathMethods::scrRandom,
+		(Script::Check)&MathChecks::chkRandom},
+	{NULL, false, NULL, NULL}};
 
 static long fRandom(long *values, unsigned prec)
-        {return (long)(((double)(*values)) * (rand()/(RAND_MAX + 0.)));};
+	{return (long)(((double)(*values)) * (rand()/(RAND_MAX + 0.)));};
 
 static long fSine(long *values, unsigned prec)
 	{return (long)(sin(values[0] * M_PI / values[1]) * values[1]);}
 
 static long fCosine(long *values, unsigned prec)
-        {return (long)(cos(values[0] * M_PI / values[1]) * values[1]);}
+	{return (long)(cos(values[0] * M_PI / values[1]) * values[1]);}
 
 static long fTangent(long *values, unsigned prec)
-        {return (long)(tan(values[0] * M_PI / values[1]) * values[1]);};
-        
+	{return (long)(tan(values[0] * M_PI / values[1]) * values[1]);};
+
 static long fArcTangent(long *values, unsigned prec)
-        {return (long)(atan(values[0] * M_PI / values[1]) * values[1]);}; 
+	{return (long)(atan(values[0] * M_PI / values[1]) * values[1]);};
 
 static long fPi(long *values, unsigned prec)
 {
-        char pi[10];
-        strcpy(pi, "3141592653");
-        pi[prec + 1] = 0;
-        return atol(pi);
+	char pi[10];
+	strcpy(pi, "3141592653");
+	pi[prec + 1] = 0;
+	return atol(pi);
 }
 
 static long fAbs(long *values, unsigned prec)
 {
-        if(*values < 0)
-                return -*values;
-        else
-                return *values;
+	if(*values < 0)
+		return -*values;
+	else
+		return *values;
 }
 
 static long fMin(long *values, unsigned prec)
 {
-        if(values[0] < values[1])
-                return values[0];
+	if(values[0] < values[1])
+		return values[0];
 
-        return values[1];
+	return values[1];
 }
 
 static long fMax(long *values, unsigned prec)
 {
-        if(values[0] > values[1])
-                return values[0];
+	if(values[0] > values[1])
+		return values[0];
 
-        return values[1];
+	return values[1];
 }
 
 static long fLimit(long *values, unsigned prec)
 {
-        if(values[0] < values[1])
-                return values[1];
+	if(values[0] < values[1])
+		return values[1];
 
-        if(values[0] > values[2])
-                return values[2];
+	if(values[0] > values[2])
+		return values[2];
 
-        return values[0];
+	return values[0];
 }
 
 static long fRound(long *values, unsigned prec)
 {
-        if(!values[1])
-                return values[0];
+	if(!values[1])
+		return values[0];
 
-        return (values[0] / values[1]) * values[1];
+	return (values[0] / values[1]) * values[1];
 }
 
 static long fSqrt(long *values, unsigned prec)
 {
-        double sq = sqrt(ScriptMethods::getDouble(*values, prec));
-        return ScriptMethods::getRealValue(sq, prec);
+	double sq = sqrt(ScriptMethods::getDouble(*values, prec));
+	return ScriptMethods::getRealValue(sq, prec);
 }
 
 static long fInt(long *values, unsigned prec)
@@ -155,18 +155,18 @@ static MathRuntime math;
 
 MathRuntime::MathRuntime() : ScriptBinder()
 {
-        addFunction("abs", 1, &fAbs);
-        addFunction("pi", 0, &fPi);
-        addFunction("min", 2, &fMin);
-        addFunction("max", 2, &fMax);
-        addFunction("round", 2, &fRound);
-        addFunction("limit", 3, &fLimit);
+	addFunction("abs", 1, &fAbs);
+	addFunction("pi", 0, &fPi);
+	addFunction("min", 2, &fMin);
+	addFunction("max", 2, &fMax);
+	addFunction("round", 2, &fRound);
+	addFunction("limit", 3, &fLimit);
 	addFunction("int", 1, &fInt);
-        addFunction("sqrt", 1, &fSqrt);
-        addFunction("sine", 2, &fSine);
-        addFunction("cosine", 2, &fCosine);
-        addFunction("tangent", 2, &fTangent);
-        addFunction("arctangent", 2, &fArcTangent);
+	addFunction("sqrt", 1, &fSqrt);
+	addFunction("sine", 2, &fSine);
+	addFunction("cosine", 2, &fCosine);
+	addFunction("tangent", 2, &fTangent);
+	addFunction("arctangent", 2, &fArcTangent);
 	addFunction("random", 1, &fRandom);
 	bind(runtime);
 }
@@ -208,7 +208,7 @@ bool MathMethods::scrSeed(void)
 
 	if(!cp)
 	{
-		snprintf(buf, sizeof(buf), "%ld", time(&now));	
+		snprintf(buf, sizeof(buf), "%ld", (long)time(&now));
 		cp = buf;
 	}
 
@@ -219,10 +219,10 @@ bool MathMethods::scrSeed(void)
 
 bool MathMethods::scrRandom(void)
 {
-        const char *cp = getMember();
-        unsigned range = 0, count = 1, roll;
-        int val, offset = 0, min = 1, max = 0, reroll = 0;
-        Symbol *sym;
+	const char *cp = getMember();
+	unsigned range = 0, count = 1, roll;
+	int val, offset = 0, min = 1, max = 0, reroll = 0;
+	Symbol *sym;
 	const char *errmsg = NULL;
 	char buf[12];
 
@@ -251,17 +251,17 @@ bool MathMethods::scrRandom(void)
 	if(cp)
 		offset = atoi(cp);
 
-        cp = getKeyword("min");
-        if(cp)
-                min = atoi(cp);
+	cp = getKeyword("min");
+	if(cp)
+		min = atoi(cp);
 
-        cp = getKeyword("max");       
-        if(cp)
-                max = atoi(cp);
+	cp = getKeyword("max");
+	if(cp)
+		max = atoi(cp);
 
-        cp = getKeyword("reroll");
-        if(cp)
-                reroll = atoi(cp);
+	cp = getKeyword("reroll");
+	if(cp)
+		reroll = atoi(cp);
 
 	while(NULL != (cp = getOption(NULL)))
 	{
@@ -277,7 +277,7 @@ bool MathMethods::scrRandom(void)
 
 retry:
 		val = offset;
-                roll = count;
+		roll = count;
 
 		while(roll--)
 			val += 1 + (int)(((double)(range)) * rand()/(RAND_MAX + 1.0));
@@ -291,7 +291,7 @@ retry:
 		if(val > max && max)
 			val = max;
 
-		snprintf(buf, sizeof(buf), "%d", val);		
+		snprintf(buf, sizeof(buf), "%d", val);
 		commit(sym, buf);
 	}
 	if(errmsg)
