@@ -1347,8 +1347,17 @@ noexec:
 		argc = 0;
 		while(argc < maxargs && NULL != (token = getToken(&pretoken)))
 		{
+			if(token[0] == '$' && token[1] == '{' && token[strlen(token) - 1] == '}')
+			{
+				token[strlen(token) - 1] = 0;
+				++token;
+				*token = '$';
+				goto insert;
+				
+			}
 			if(token[0] == '$' && isalpha(token[1]))
 			{
+insert:
 				if(!stricmp(token, "$script.name"))
 					token = alloc((char *)basename);
 				else if(!stricmp(token, "$script.file"))
