@@ -96,6 +96,13 @@ void *ScriptImage::getMemory(size_t size)
 	return alloc(size);
 }
 
+const char *ScriptImage::dupString(const char *str)
+{
+	char *cp = (char *)alloc(strlen(str) + 1);
+	strcpy(cp, str);
+	return (const char *)cp;
+}
+
 void ScriptImage::fastBranch(ScriptInterp *interp)
 {
 	return;
