@@ -317,7 +317,7 @@ Script::Symbol *ScriptInterp::mapDirect(const char *id, unsigned short size)
 	}
 
 retry:
-	if(!isalpha(*id) && *id != '_')
+	if(!isalnum(*id) && *id != '_')
 	{
 		logmissing(id, "invalid");
 		return NULL;
@@ -1290,18 +1290,47 @@ const char *ScriptInterp::hasOption(void)
 
 const char *ScriptInterp::getOption(const char *def)
 {
+	register const char *cp;
+	unsigned current;
+
+get:
 	for(;;)
 	{
 		if(frame[stack].index >= frame[stack].line->argc)
 			return (char *)def;
 
-		if(*frame[stack].line->args[frame[stack].index] != '=')
+		cp = frame[stack].line->args[frame[stack].index];
+
+		if(stack && !stricmp(cp, "%*"))
+			goto expand;
+
+		if(*cp != '=')
 			break;
 
 		frame[stack].index += 2;
 	}
 
-	return frame[stack].line->args[frame[stack].index++];
+	++frame[stack].index;
+	return cp;
+
+expand:
+	current = stack;
+	while(stack && frame[stack].local == frame[current].local)
+		--stack;
+	if(frame[stack].local == frame[current].local)
+	{
+		stack = current;
+		goto get;
+	}
+	if(frame[stack].index >= frame[stack].line->argc)
+		frame[stack].index = 0;
+	cp = getOption(NULL);
+	if(!cp || frame[stack].index >= frame[stack].line->argc)
+		++frame[current].index;
+	stack = current;
+	if(!cp)
+		goto get;
+	return cp;
 }
 
 const char *ScriptInterp::getSymbol(const char *id)
@@ -1452,6 +1481,22 @@ const char *ScriptInterp::getContent(const char *opt)
 		a = (Array *)&sym->data;
 		switch(sym->type)
 		{
+		case symBOOL:
+			switch(sym->data[0])
+			{
+			case '0':
+			case 'n':
+			case 'N':
+			case 'f':
+			case 'F':
+				tmp[0] = '0';
+				break;
+			default:
+				tmp[0] = '1';
+				break;
+			}
+			tmp[1] = 0;
+			return tmp;
 		case symARRAY:
 			snprintf(tmp, 11, "%d", a->tail);
 			return tmp;
