@@ -1427,7 +1427,7 @@ bool ScriptMethods::scrVar(void)
 	Line *line = getLine();
 	const char *value = getKeyword("value");
 
-	if(!stricmp(line->cmd, "char"))
+	if(!stricmp(line->cmd, "char") || !stricmp(line->cmd, "bool"))
 		size = 1;
 
 	if(cp)
@@ -1451,6 +1451,12 @@ bool ScriptMethods::scrVar(void)
 			errmsg = "var-already-defined";
 			continue;
 		}
+		if(!stricmp(line->cmd, "bool"))
+		{
+			sym->type = symBOOL;
+			if(!value)
+				commit(sym, "false");
+		}
 		if(value)
 			commit(sym, value);
 	}
@@ -1883,6 +1889,8 @@ bool ScriptMethods::scrCall(void)
 	const char *cp, *vp;
 	unsigned idx = 0;
 	Symbol *sym;
+	unsigned argc = 0;
+	char argn[8];
 
 	if(!push())
 	{
@@ -1911,20 +1919,44 @@ bool ScriptMethods::scrCall(void)
 	{
 		cp = line->args[idx++];
 		if(*cp != '=')
+		{
+			if(!argc)
+			{
+				++argc;
+				continue;
+			}
+			snprintf(argn, sizeof(argn), "%d", argc++);
+			if(*cp == '&')
+			{
+				vp = cp;
+				cp = argn;
+				goto byref;
+			}
+			--stack;
+			cp = getContent(cp);
+			++stack;
+			setConst(argn, cp);
 			continue;
+		}
 
 		++cp;
 		vp = line->args[idx++];
 		if(*vp == '&')
 		{
+byref:
 			--stack;
 			sym = mapSymbol(vp);
 			++stack;
  			frame[stack].local->setReference(cp, sym);
 			continue;
 		}
-		setConst(cp, getKeyword(cp));
+		--stack;
+		vp = getKeyword(cp);
+		++stack;
+		setConst(cp, vp);
 	}
+	snprintf(argn, sizeof(argn), "%d", --argc);
+	setConst("_", argn);
 	return redirect(false);
 }
 
