@@ -287,6 +287,10 @@ void Script::clear(Symbol *sym)
 		a->head = a->tail = 0;
 		sym->data[sizeof(Array)] = 0;
 		return;
+	case symBOOL:
+		sym->data[0] = 'n';
+		sym->data[1] = 0;
+		return;
 	case symNUMBER:
 		dec = sym->size - 11;
 		if(dec)
@@ -398,6 +402,7 @@ const char *Script::extract(Symbol *sym)
 	case symNORMAL:
 	case symCONST:
 	case symNUMBER:
+	case symBOOL:
 		return sym->data;
 	case symTIMER:
 		if(sym->data[0])
@@ -457,6 +462,7 @@ bool Script::append(Symbol *sym, const char *value)
 {
 	switch(sym->type)
 	{
+	case symBOOL:
 	case symNUMBER:
 	case symPROPERTY:
 	case symCOUNTER:
@@ -498,6 +504,22 @@ bool Script::commit(Symbol *sym, const char *value)
 
 	switch(sym->type)
 	{
+	case symBOOL:
+		if(atol(value))
+			sym->data[0] = 'y';
+		else switch(*value)
+		{
+		case '0':
+		case 'n':
+		case 'N':
+		case 'f':
+		case 'F':
+			sym->data[0] = 'n';
+		default:
+			sym->data[0] = 'y';
+		};
+		sym->data[1] = 0;
+		return true;					
 	case symNUMBER:
 		v1 = atol(value);
 		sp = strchr(value, '.');
