@@ -958,6 +958,14 @@ public:
 	 */
 	void *getMemory(size_t size);
 
+	/**
+	 * Duplicate string...
+	 *
+	 * @return memory pointer.
+	 * @param string requested.
+	 */
+	const char *dupString(const char *str);
+
 	/**
 	 * Fast branch linkback code.
 	 */
